timespantools.offset_happens_when_timespan_starts
=================================================

.. autofunction:: abjad.tools.timespantools.offset_happens_when_timespan_starts.offset_happens_when_timespan_starts
